crabnet.data.benchmark\_data.aflow\_\_agl\_thermal\_conductivity\_300K package
==============================================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.aflow__agl_thermal_conductivity_300K
   :members:
   :undoc-members:
   :show-inheritance:
